rook_sdk_health_connect library
Classes
- AndroidPermissionsSummary
- This class represents a summary of the Android permissions that have been granted to the app.
- AndroidStepsCounter
- Entry point for managing the Android step counter service and retrieving the current day's step count.
- AndroidStepsManager
- Helper class to manage steps from Android system.
- HCRookBackgroundSync
- This class allows you to schedule an periodic background health data syncs.
- HCRookConfigurationManager
- Helper class used to configure and initialize the SDK, and manage the current user.
- HCRookHealthPermissionsManager
- Helper class to request/check permissions used by this SDK.
- HCRookHelpers
- Helper functions for Rook SDK.
- HCRookSyncManager
- HealthConnectPermissionsSummary
- This class represents a summary of the Health Connect permissions that have been granted to the app.
Enums
- HCAvailabilityStatus
- This enum represents the current state of the Health Connect APK
- HCBackgroundReadStatus
- This enum represents the current state of the background read feature.
- HCEventSyncType
- HCSummarySyncType